@@ -11,6 +11,7 @@
 (custom-add-loads 'ispell '("flyspell"))
 (custom-add-loads 'tools '("autoinsert" "folding"))
 (custom-add-loads 'hypermedia '("css-mode" "htmlize"))
+(custom-add-loads 'desktop-entry '("desktop-entry-mode"))
 (custom-add-loads 'css '("css-mode"))
 (custom-add-loads 'outlines '("whitespace-mode"))
 (custom-add-loads 'hexl '("hexl"))
@@ -20,10 +21,12 @@
 (custom-add-loads 'scribe '("scribe"))
 (custom-add-loads 'auto-insert '("autoinsert"))
 (custom-add-loads 'htmlize '("htmlize"))
+(custom-add-loads 'desktop-entry-faces '("desktop-entry-mode"))
 (custom-add-loads 'flyspell '("flyspell"))
-(custom-add-loads 'languages '("auto-autoloads" "crontab" "css-mode" "winmgr-mode" "xrdb-mode"))
+(custom-add-loads 'languages '("auto-autoloads" "crontab" "css-mode" "desktop-entry-mode" "winmgr-mode" "xrdb-mode"))
 (custom-add-loads 'fill '("filladapt"))
 (custom-add-loads 'folding '("folding"))
+(custom-add-loads 'faces '("desktop-entry-mode"))
 (custom-add-loads 'processes '("ansi-color" "flyspell"))
 (custom-add-loads 'wp '("rtf-support" "scribe"))
 (custom-add-loads 'po '("po-mode"))
